summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolder.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolder.h')
-rw-r--r--kmail/kmfolder.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/kmfolder.h b/kmail/kmfolder.h
index 60db2666..82d586a2 100644
--- a/kmail/kmfolder.h
+++ b/kmail/kmfolder.h
@@ -273,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
/** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */
- void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
- const KMMsgtqStatus newtqStatus,
+ void msgStatusChanged( const KMMsgStatus oldStatus,
+ const KMMsgStatus newStatus,
int idx);
/** Open folder for access.
@@ -490,10 +490,10 @@ public:
int writeIndex( bool createEmptyIndex = false );
/** Set the status of the message at index @p idx to @p status. */
- void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
+ void seStatus(int idx, KMMsgStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
+ void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
/** Icon related methods */
bool useCustomIcons() const { return mUseCustomIcons; }
@@ -273,10 +273,10 @@ public:
contained by this folder */
int countUnreadRecursive();
- /** Called by KMMsgBase::setqStatus when status of a message has changed
+ /** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */